==> 5.8.0.tar.gz: ciphey/translations/hu/CODE_OF_CONDUCT.md <==
# Közreműködői magatartási kódex

## Zálogunk

A nyitott és barátságos környezet elősegítése érdekében, mi, 
a közreműködők és fenntartók ígéretet teszünk arra, hogy részt veszünk projektünkben, és
mindent megteszünk, hogy közösségünk zaklatásmentes élményt nyújtson mindenkinek, 
kortól, testtől, mérettől, fogyatékosságtól, etnikumtól, nemi jellemzőktől, nemi identitás és kifejezés,
tapasztalati szint, végzettség, társadalmi-gazdasági helyzet, nemzetiség, személyes
megjelenés, faj, vallás vagy szexuális identitás és orientációtól függetlenül.

## Szabványaink

Példák olyan viselkedésre, melyek hozzájárulnak a pozitív környezet kialakításához:

* Üdvözlő és befogadó nyelv használata
* Tiszteletben tartani az eltérő nézőpontokat és tapasztalatokat
* Építő kritikák elfogadása
* Összpontosítás arra, ami a közösség számára a legjobb
* Empátia mutatása a közösség többi tagjával szemben


Példák a résztvevők által elfogadhatatlan viselkedésre:

* Szexualizált nyelvezet vagy képek használata és nem kívánt szexuális figyelem vagy tolakodáss
* Trollkodás, sértő / becsmérlő megjegyzések és személyes vagy politikai támadások
* Nyilvános vagy magán zaklatás
* Mások személyes adatainak, például fizikai vagy elektronikus címének közzététele kifejezett engedély nélkül
* Egyéb magatartás, amely szakmai körülmények között ésszerűen helytelennek tekinthető

## Feladataink

A projekt fenntartói felelősek az elfogadható szabványok tisztázásáért
viselkedését, és várhatóan megfelelő és tisztességes korrekciós intézkedéseket foganatosítanak
válaszként az elfogadhatatlan viselkedés esetére.

A projektfenntartóknak joguk és felelősségük van eltávolítani, szerkeszteni vagy
elutasítani azokat a megjegyzéseket, elkötelezettségeket, kódokat, wiki-szerkesztéseket, kérdéseket és az egyéb hozzászólásokat amelyek nem felelnek meg ennek a magatartási kódexnek, vagy ideiglenesen vagy
tartósan közreműködő más magatartás miatt, amelyet nem tartunk megfelelőnek, fenyegető, sértő vagy káros.

## Hatály

Ez a magatartási kódex a projekttereken és a nyilvános tereken egyaránt érvényes
amikor az egyén képviseli a projektet vagy közösségét. Például
egy projekt vagy közösség képviseletéhez tartozik egy hivatalos projekt e-mail használata, egy hivatalos közösségi médiafiókon keresztül történő közzététel, vagy kinevezettként való eljárás
képviselője egy online vagy offline eseményen. A projekt képviseletét
tovább meghatározzák és pontosítják a projektfenntartók.

## Végrehajtás

Erőszakos, zaklató vagy más módon elfogadhatatlan viselkedés
jelenltésre kerül a projekt csapatával. Minden panaszt felül fognak vizsgálni és kivizsgálják, és a körülményekhez megfelelőnek tekinthető választ fognak adni. A projekt csapata
köteles megőrizni a titoktartást az eseménnyel kapcsolatban.
A konkrét végrehajtási irányelvek további részleteit külön közzétehetjük.

Azok a projektfenntartók, akik nem követik és nem tartják be megfelelően a magatartási kódexet, bizalmi megvonásban részesülnek átmenetileg vagy véglegesen a projekt vezetésének tagjai által.

## Hozzárendelés

Ez a magatartási kódexet a [Contributor Covenant][homepage], formájára készült, version 1.4,
elérhető https://www.contributor-covenant.org/version/1/4/code-of-conduct.html

[honlap]: https://www.contributor-covenant.org

A magatartási kódex-szel kapcsolatos gyakori kérdésekre adott válaszokért lásd:https://www.contributor-covenant.org/faq

==> 5.10.0.tar.gz: ciphey/translations/hu/CODE_OF_CONDUCT.md <==
# Közreműködői magatartási kódex

## Zálogunk

A nyitott és barátságos környezet elősegítése érdekében, mi,
a közreműködők és fenntartók ígéretet teszünk arra, hogy részt veszünk projektünkben, és
mindent megteszünk, hogy közösségünk zaklatásmentes élményt nyújtson mindenkinek,
kortól, testtől, mérettől, fogyatékosságtól, etnikumtól, nemi jellemzőktől, nemi identitás és kifejezés,
tapasztalati szint, végzettség, társadalmi-gazdasági helyzet, nemzetiség, személyes
megjelenés, faj, vallás vagy szexuális identitás és orientációtól függetlenül.

## Szabványaink

Példák olyan viselkedésre, melyek hozzájárulnak a pozitív környezet kialakításához:

- Üdvözlő és befogadó nyelv használata
- Tiszteletben tartani az eltérő nézőpontokat és tapasztalatokat
- Építő kritikák elfogadása
- Összpontosítás arra, ami a közösség számára a legjobb
- Empátia mutatása a közösség többi tagjával szemben

Példák a résztvevők által elfogadhatatlan viselkedésre:

- Szexualizált nyelvezet vagy képek használata és nem kívánt szexuális figyelem vagy tolakodáss
- Trollkodás, sértő / becsmérlő megjegyzések és személyes vagy politikai támadások
- Nyilvános vagy magán zaklatás
- Mások személyes adatainak, például fizikai vagy elektronikus címének közzététele kifejezett engedély nélkül
- Egyéb magatartás, amely szakmai körülmények között ésszerűen helytelennek tekinthető

## Feladataink

A projekt fenntartói felelősek az elfogadható szabványok tisztázásáért
viselkedését, és várhatóan megfelelő és tisztességes korrekciós intézkedéseket foganatosítanak
válaszként az elfogadhatatlan viselkedés esetére.

A projektfenntartóknak joguk és felelősségük van eltávolítani, szerkeszteni vagy
elutasítani azokat a megjegyzéseket, elkötelezettségeket, kódokat, wiki-szerkesztéseket, kérdéseket és az egyéb hozzászólásokat amelyek nem felelnek meg ennek a magatartási kódexnek, vagy ideiglenesen vagy
tartósan közreműködő más magatartás miatt, amelyet nem tartunk megfelelőnek, fenyegető, sértő vagy káros.

## Hatály

Ez a magatartási kódex a projekttereken és a nyilvános tereken egyaránt érvényes
amikor az egyén képviseli a projektet vagy közösségét. Például
egy projekt vagy közösség képviseletéhez tartozik egy hivatalos projekt e-mail használata, egy hivatalos közösségi médiafiókon keresztül történő közzététel, vagy kinevezettként való eljárás
képviselője egy online vagy offline eseményen. A projekt képviseletét
tovább meghatározzák és pontosítják a projektfenntartók.

## Végrehajtás

Erőszakos, zaklató vagy más módon elfogadhatatlan viselkedés
jelenltésre kerül a projekt csapatával. Minden panaszt felül fognak vizsgálni és kivizsgálják, és a körülményekhez megfelelőnek tekinthető választ fognak adni. A projekt csapata
köteles megőrizni a titoktartást az eseménnyel kapcsolatban.
A konkrét végrehajtási irányelvek további részleteit külön közzétehetjük.

Azok a projektfenntartók, akik nem követik és nem tartják be megfelelően a magatartási kódexet, bizalmi megvonásban részesülnek átmenetileg vagy véglegesen a projekt vezetésének tagjai által.

## Hozzárendelés

Ez a magatartási kódexet a [Contributor Covenant][homepage], formájára készült, version 1.4,
elérhető <https://www.contributor-covenant.org/version/1/4/code-of-conduct.html>

[honlap]: https://www.contributor-covenant.org

A magatartási kódex-szel kapcsolatos gyakori kérdésekre adott válaszokért lásd:<https://www.contributor-covenant.org/faq>
